###JJdist
"""
This module is created as the part of excercise undertaken in the Udacity and AWS foundation Machine learning Course.

The package consists of mathematical calculations for Binomial distribution and Gausssian distribution

Please refer to code to understand the modules, functions their arguments and returns
"""